package com.weaver.seconddev.jcldoor.controller;

import com.weaver.common.authority.annotation.WeaPermission;
import com.weaver.common.base.entity.result.WeaResult;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.jcldoor.service.JucailinPortalService;
import com.weaver.seconddev.jcldoor.util.CommonUtils;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import com.weaver.workflow.common.constant.list.listdimension.RequestListInitDimensionTabEnum;
import com.weaver.workflow.common.entity.list.api.RequestListConditionApiEntity;
import com.weaver.workflow.common.entity.list.api.publicapi.RequestListInfoPAEntity;
import com.weaver.workflow.list.api.rest.publicapi.WflRequestListRest;
import groovy.util.logging.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Slf4j
@RestController
@RequestMapping("/api/secondev/njjucailin/portal")
public class JucailinPortalController {


    private final Logger log = LoggerFactory.getLogger(JucailinPortalController.class);

    @Autowired
    private JucailinPortalService jucailinPortalService;

    @RpcReference(group = "workflow")
    WflRequestListRest wflRequestListRest;

    /**
     * 人员基本信息接口
     * @param request
     * @return
     */
    @GetMapping("/getPortalUser")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalUser(HttpServletRequest request){
        log.error("getPortalUser");
        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalUserData(simpleEmployee);
        }catch (Exception e){
            log.error("getPortalUser-Exception:"+e);
        }
        return WeaResult.success(recordMap);
    }

    /**
     *
     * @param request
     * @return
     */
    @GetMapping("/getPortalAttendance")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalAttendance(HttpServletRequest request){
        log.error("getPortalAttendance");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        Long employeeId = UserContext.getCurrentEmployeeId();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalAttendanceData(simpleEmployee);
        }catch (Exception e){
            log.error("testSapi-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    @GetMapping("/getPortalPerformance")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalPerformance(HttpServletRequest request){
        log.error("getPortalPerformance");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        Long employeeId = UserContext.getCurrentEmployeeId();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalPerformanceData(simpleEmployee);
        }catch (Exception e){
            log.error("testSapi-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    /**
     * 人员工作成就信息
     * @param request
     * @return
     */
    @GetMapping("/getPortalWorkAchievement")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalWorkAchievement(HttpServletRequest request){
        log.error("getPortalWorkAchievement");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalWorkAchievement(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalWorkAchievement-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }

    /**
     * 人员工作成就信息
     * @param request
     * @return
     */
    @GetMapping("/getPortalBirthdayWishes")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalBirthdayWishes(HttpServletRequest request){
        log.error("getPortalBirthdayWishes");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalBirthdayWishes(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalBirthdayWishes-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    /**
     * 风险信息
     * @param request
     * @return
     */
    @GetMapping("/getPortalRiskInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalRiskInfo(HttpServletRequest request){
        log.error("getPortalRiskInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();

        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        try{
            recordMap = jucailinPortalService.getPortalRiskInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalRiskInfo-Exception:"+e);
        }

        return WeaResult.success(recordMap);
    }


    /**
     * 绩效信息
     * @param request
     * @return
     */
    @GetMapping("/getPortalPerformanceInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<Object> getPortalPerformanceInfo(HttpServletRequest request){
        log.error("getPortalPerformanceInfo");

        Map<String, Object> recordMap = new HashMap<String, Object>();
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();
        try{
            recordMap = jucailinPortalService.getPortalPerformanceInfo(request,simpleEmployee);
        }catch (Exception e){
            log.error("getPortalPerformanceInfo-Exception:"+e.getMessage());
        }

        return WeaResult.success(recordMap);
    }



    /**
     * 流程信息（我发起的）
     * @param request
     * @return
     */
    @GetMapping("/getWorkFlowInfo")
    @WeaPermission(publicPermission = true)
    public WeaResult<List<RequestListInfoPAEntity>> getWfInfoCreate(HttpServletRequest request){
        log.error("getWorkFlowInfo");
        try{
            RequestListConditionApiEntity conditionEntity = new RequestListConditionApiEntity();
            SimpleEmployee employee = new SimpleEmployee();
            String keyword = CommonUtils.null2String(request.getParameter("keyword"));
            if(!"".equals(keyword)){
                conditionEntity.setRequestname(keyword);
            }

            String type = CommonUtils.null2String(request.getParameter("type"));
            int pageSize = CommonUtils.getIntValue(request.getParameter("pageSize"),10);
            int pageNo = CommonUtils.getIntValue(request.getParameter("pageNo"),1);

            // 0 我发起的； 1 我的待办； 2  我的已办
            if("0".equals(type)){
                return  wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.PORTAL_MINE.getTabid(), pageNo, pageSize, conditionEntity);
            }else if("1".equals(type)){
                return  wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.TODO_FLOWALL.getTabid(), pageNo, pageSize, conditionEntity);
            }else if("2".equals(type)){
                return  wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.DONE_FLOWALL.getTabid(), pageNo, pageSize, conditionEntity);
            }else{
                return  wflRequestListRest.getRequestListByTabId(employee, RequestListInitDimensionTabEnum.PORTAL_MINE.getTabid(), pageNo, pageSize, conditionEntity);
            }
        }catch (Exception e){
            log.error("getWorkFlowInfo-Exception:"+e.getMessage());
        }
        return null;
    }






}
